<?php
/**
 * RegistroBCAGED
 *
 * @package    Logic
 * @subpackage Registro/Caged
 *
 * @author     thalesvalias - 22/05/2012
 *
 */
class RegistroBCAGED extends RegistroCAGED{

    const REGISTRO_B = 'B';
    const SEQUENCIA = '00000';

    private $_estrutura;
    private $_tpInscricao;
    private $_nrInscricao;
    private $_primeiraDeclaracao;
    private $_alteracaoDeclaracao;
    private $_totalEmpregados;


    /**
     * Gera Tipo de Registro B.
     *
     * @return void
     *
     * @author thalesvalias - 22/05/2012
     */
    public function geraRegistroB(){
        $this->_geraRegistro();
    }


    /**
     * Atribui os dados no atributo da classe Pai.
     *
     * @return void
     *
     * @author thalesvalias - 22/05/2012
     */
    private function _geraRegistro(){
        // Bloco 1 eh gerado no pai.
        parent::geraRegistro(self::REGISTRO_B, null, null);

        // Bloco 2 | 002 | Tipo de Identificacao.
        $this->atribuiDado($this->_tpInscricao, 1);

        // Bloco 3 | 003-016 | Numero do Identificador do Estabelecimento.
        $this->atribuiDado($this->_nrInscricao, 14, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 4 | 017-021 | Sequencia.
        $this->atribuiDado(self::SEQUENCIA, 5);

        // Bloco 5 | 022 | Primeira Declaracao (1-primeira declaracao / 2-ja informou antes).
        // Passando o 2 fixo, conforme ao Arte.
        $this->atribuiDado($this->_primeiraDeclaracao, 1);

        // Bloco 6 | 023 | Alteracao (1-nenhuma / 2-dados cadastrais / 3-encerramento de atividade).
        // Passando o 2 fixo, conforme ao Arte.
        $this->atribuiDado($this->_alteracaoDeclaracao, 1);

        // Bloco 7 | 024-031 | CEP.
        $this->atribuiDado($this->_estrutura->endereco->getNrcependereco(), 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 8 | 032-036 | Filler.
        $this->atribuiDado(parent::CARACTER_BRANCO, 5, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 9 | 037-076 | Razao Social.
        $this->atribuiDado($this->_estrutura->historico->getNmrazsocestrut(), 40, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        //atribui endereco
        $this->atribuiDado($this->_estrutura->endereco->getDsendereco(), 35, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        //atribui numero do endereco
        $this->atribuiDado($this->_estrutura->endereco->getNumero(), 5, parent::CARACTER_BRANCO, parent::PREENCHE_ESQUERDA);

        // Bloco 11 | 117-136 | Bairro.
        $this->atribuiDado($this->_estrutura->endereco->bairro, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 12 | 137-138 | UF.
        $this->atribuiDado($this->_estrutura->endereco->getSgestado(), 2, parent::CARACTER_BRANCO);

        // Bloco 13 | 139-143 | Total de Empregados existentes no primeiro dia do mes de competencia.
        $this->atribuiDado($this->_totalEmpregados."", 5,  parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 14 | 144
        /* 1. Microempresa para a pessoa jurídica, ou a ela equiparada, que auferir, em cada ano-calendário, receita bruta igual ou inferior a R$
        240.000,00 (duzentos e quarenta mil reais).
        * 2. Empresa de Pequeno Porte para a pessoa jurídica, ou a ela equiparada, que auferir, em cada ano-calendário, receita bruta superior a R$
        240.000,00 (duzentos e quarenta mil reais) e igual ou inferior a R$ 2.400.000,00 (dois milhões e quatrocentos mil reais).
        * 3. Empresa/Órgão não classificados este campo só deve ser selecionado se o estabelecimento não se enquadrar como microempreendedor
        individual, microempresa ou empresa de pequeno porte.
        * 4. Microempreendedor Individual para o empresário individual que tenha auferido receita bruta, no ano-calendário anterior, de até
        R$36.000,00 (trinta e seis mil reais).
        */
        $this->atribuiDado($this->_estrutura->historico->getIdtipoempr(), 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 15 | 145-151 | Subclasse CNAE 2.0.
        $this->atribuiDado($this->_estrutura->historico->getCdcnae(), 7, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 16 | 152-155 | DDD.
        $this->atribuiDado($this->_estrutura->endereco->ddd, 4, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 17 | 156-163 | Telefone.
        $this->atribuiDado($this->_estrutura->endereco->telefone, 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 18 | 164-213 | Email.
        $this->atribuiDadoEspecial($this->_estrutura->endereco->email, 50,  parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 19 | 214-240 | Filler.
        $this->atribuiDado(parent::CARACTER_BRANCO, 27, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

    }


    public function setEstrutura($estrutura)
    {
        $this->_estrutura = $estrutura;
    }


    public function setNrInscricao($nrInscricao)
    {
        $this->_nrInscricao = $nrInscricao;
    }


    public function setTpInscricao($tpInscricao)
    {
        $this->_tpInscricao = $tpInscricao;
    }


    public function setAlteracaoDeclaracao($alteracaoDeclaracao)
    {
        $this->_alteracaoDeclaracao = $alteracaoDeclaracao;
    }


    public function setPrimeiraDeclaracao($primeiraDeclaracao)
    {
        $this->_primeiraDeclaracao = $primeiraDeclaracao;
    }


    public function setTotalEmpregados($totalEmpregados)
    {
        $this->_totalEmpregados = $totalEmpregados;
    }



}