--/******************************************************************************/
--/* Sistemas Integrados TECNISA                                                */
--/******************************************************************************/
--/*                                                                            */
--/* Nome: USR_STP_INTERFACE_TECNISA                                            */
--/*                                                                            */
--/* Descrio:                                                                 */
--/* Gera lanamento de estoque no Sistema Tecfood a partir de lanamentos de   */
--/* entrada no sistema hospitalar                                              */
--/*                                                                            */
--/* Criao:                                                                   */
--/* 05/02/2004 - Roberto Martins                                               */
--/* @C:\web_560\sql\end_conv\oracle\clientes\hal\0001_USR_STP_INTERFACE_TECNISA.SQL */
--/******************************************************************************/
--/*P_RECB_SEQUENCIA          Sequencial chave do lancamento na tabela do HA    */
--/*P_DT_RECEBIMENTO          Data da movimentao de estoque                   */
--/*P_MATR_CODIGO             Cdigo do produto no sistema HA                   */
--/*P_QT_VALIDADA             Quantidade movimentada                            */
--/*P_VL_UNITARIO_NOTA_FISCAL Valor unitrio do tem                            */
--/*P_PC_DESCONTO             Valor do desconto percentual do tem              */
--/*P_CDEMPRESA               Cdigo da empresa de lanamento                   */
--/*P_IDENTRSAIDOP            Indentificador "E"ntrada ou "S"ada do estoque    */
--/*P_IDINCLUSAO              Indentificador "I"ncluso ou "E"xcluso do tem   */
--/*P_ALMOXARIFADO            Almoxarifado de entrada do produto                */
--/******************************************************************************/
--/*USR_STP_INTERFACE_TECNISA(1,1,'18/05/2004',100329,100,8.90,0,'100','E','I') */
--/*EXECUTE USR_STP_INTERFACE_TECNISA('99003344','05/11/2005',604429,55,100,0,'01','S','I','98','100104064501','000000000999');*/
--/******************************************************************************/

CREATE OR REPLACE PROCEDURE USR_STP_INTERFACE_TECNISA
   (P_RECB_SEQUENCIA          IN LANCTOESTOQ.USR_RECB_SEQUENCIA%TYPE,
    P_DT_RECEBIMENTO          IN LANCTOESTOQ.DTLANCESTQ%TYPE,
    P_MATR_CODIGO             IN NUMBER,
    P_QT_VALIDADA             IN ITLANCTOEST.QTLANCTOEST%TYPE,
    P_VL_UNITARIO_NOTA_FISCAL IN ITLANCTOEST.VRUNILANCTO%TYPE,
    P_PC_DESCONTO             IN ITEMPRODUTO.VRDESPERITEM%TYPE,
    P_CDEMPRESA               IN NUMBER,
    P_IDENTRSAIDOP            IN LANCTOESTOQ.IDENTRSAIDOP%TYPE,
    P_IDINCLUSAO              IN LANCTOESTOQ.IDENTRSAIDOP%TYPE DEFAULT 'I',
    P_ALMOXARIFADO            IN ITLANCTOEST.CDALMOXARIFE%TYPE DEFAULT ' ',
    P_CDSERVFILI              IN VARCHAR,
    P_CDOPERADOR              IN OPERADOR.CDOPERADOR%TYPE)

IS

   V_CDFILIAL     VARCHAR2(04);
   V_NRLANCTONF   VARCHAR2(20);
   V_NRRETIRADA   VARCHAR2(20);
   V_NRLANCESTQ   VARCHAR2(20);
   V_CDFILIMOVI   VARCHAR2(04);
   V_CDEMPRESA    VARCHAR2(02);
   V_CDINSCESTA   VARCHAR2(16);
   V_CDINSCMUNI   VARCHAR2(16);
   V_CDSERVFILI   VARCHAR2(05);

   V_NRSEQITPROD  VARCHAR2(04);
   V_CDPRODUTO    VARCHAR2(10);
   V_CDPRODESTO   VARCHAR2(10);
   V_NMPRODUTO    VARCHAR2(50);
   V_VRFATOCONV   NUMBER;
   V_VRTOTAITEM   NUMBER;
   V_VRCONTITEM   NUMBER;

   V_DTAUXILIAR   DATE;
   V_DTINICIAL    DATE;
   V_DTFINAL      DATE;

   V_NRCARDAPIO   VARCHAR2(10);
   V_TIES_CODIGO  NUMBER;

BEGIN
   /*Verificao se o produto  um alimento*/
   BEGIN
      SELECT MAEM.TIES_CODIGO
      INTO V_TIES_CODIGO
      FROM HAESTQ.MATERIAIS_EMPRESAS MAEM
      WHERE MAEM.MATR_CODIGO = P_MATR_CODIGO;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   IF (V_TIES_CODIGO = 2) THEN
      /*Somente realiza a atualizao se produto possuir cdigo de integrao*/
      SELECT MAX(CDPRODUTO), MAX(CDPRODESTO), MAX(NMPRODUTO), MAX(VRFATOCONV)
      INTO V_CDPRODUTO, V_CDPRODESTO, V_NMPRODUTO, V_VRFATOCONV
      FROM PRODUTO
      WHERE TO_NUMBER(NVL(CDPRODINTE,'0')) = P_MATR_CODIGO;

      SELECT NVL(MAX(CDFILIAL),'0001')
      INTO V_CDFILIMOVI
      FROM FILIAL
      WHERE CDEMPRESAP = LPAD(TO_CHAR(P_CDEMPRESA),3,'0');

      IF V_CDFILIMOVI = '0001' THEN

         SELECT MAX(CDSERVFILI)
         INTO V_CDSERVFILI
         FROM SERVICO
         WHERE CDFILIAL       = V_CDFILIMOVI  AND
               USR_CDCENTCUST = P_CDSERVFILI;

         IF (P_IDINCLUSAO = 'I') AND (V_CDPRODUTO IS NOT NULL) THEN

            IF ((V_CDSERVFILI IS NOT NULL) OR (P_IDENTRSAIDOP = 'E')) THEN

            /*Verificao se o corpo do lanamento j existe no banco*/
               SELECT MAX(L.CDFILIAL),   MAX(L.NRLANCTONF), MAX(L.NRLANCESTQ),
                      MAX(L.DTLANCESTQ), MAX(R.NRRETIRADA), MAX(NRCARDAPIO)
               INTO V_CDFILIAL,   V_NRLANCTONF, V_NRLANCESTQ,
                    V_DTAUXILIAR, V_NRRETIRADA, V_NRCARDAPIO
               FROM LANCTOESTOQ L, RETIRADA R
               WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA   AND
                     L.NRLANCESTQ       = R.NRLANCESTQ       AND
                     L.CDFILIAL         = R.CDFILANCESTQ;

               /*Excluso na tabela de itens da nota fiscal*/
               DELETE FROM ITEMPRODUTO
               WHERE CDPRODUTO          = V_CDPRODUTO AND
                     USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

               DELETE FROM ITEMRETI
               WHERE CDPRODUTO     = V_CDPRODUTO   AND
                     NRLANCESTQ    = V_NRLANCESTQ  AND
                     CDFILIAL      = V_CDFILIMOVI;

               /*Excluso na tabela de itens de estoque*/
               DELETE FROM ITLANCTOEST
               WHERE CDPRODUTO          = V_CDPRODUTO AND
                     USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

               IF (P_QT_VALIDADA <> 0) THEN

                  IF V_CDFILIAL IS NULL THEN

                     V_CDFILIAL  := V_CDFILIMOVI;

                     /*Sequencial para chave das tabelas de lanamento*/
                     IF (P_IDENTRSAIDOP = 'E') THEN
                        /*Tabela Nota Fiscal*/
                        SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQUENCIAL),'0')) + 1),10,'0')
                        INTO V_NRLANCTONF
                        FROM NOVOCODIGO
                        WHERE CDCONTADOR = 'LANCNF/FILIAL' || V_CDFILIMOVI;

                        IF V_NRLANCTONF = '0000000001' THEN
                           INSERT INTO NOVOCODIGO
                              (CDCONTADOR, NRSEQUENCIAL)
                           VALUES
                              ('LANCNF/FILIAL' || V_CDFILIMOVI, LPAD(V_NRLANCTONF,20,'0'));
                        ELSE
                           UPDATE NOVOCODIGO
                           SET NRSEQUENCIAL = LPAD(V_NRLANCTONF,20,'0')
                           WHERE CDCONTADOR = 'LANCNF/FILIAL' || V_CDFILIMOVI;
                        END IF;
                     ELSE

                        /*Tabela Retirada*/
                        SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQUENCIAL),'0')) + 1),10,'0')
                        INTO V_NRRETIRADA
                        FROM NOVOCODIGO
                        WHERE CDCONTADOR = 'RETIRADA' || V_CDFILIMOVI;

                        IF V_NRRETIRADA = '0000000001' THEN
                           INSERT INTO NOVOCODIGO
                              (CDCONTADOR, NRSEQUENCIAL)
                           VALUES
                              ('RETIRADA' || V_CDFILIMOVI, LPAD(V_NRRETIRADA,20,'0'));
                        ELSE
                           UPDATE NOVOCODIGO
                           SET NRSEQUENCIAL = LPAD(V_NRRETIRADA,20,'0')
                           WHERE CDCONTADOR = 'RETIRADA' || V_CDFILIMOVI;
                        END IF;

                        SELECT MAX(NRCARDAPIO)
                        INTO V_NRCARDAPIO
                        FROM CARDADIA
                        WHERE (CDFILIAL   = V_CDFILIMOVI)   AND
                              (CDSERVFILI = V_CDSERVFILI)   AND
                              (DTCARDAPIO = TRUNC(P_DT_RECEBIMENTO));

                        IF (V_NRCARDAPIO IS NULL) THEN
                           SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQUENCIAL),'0')) + 1),10,'0')
                           INTO V_NRCARDAPIO
                           FROM NOVOCODIGO
                           WHERE CDCONTADOR = 'CARDAPIO' || V_CDFILIMOVI;

                           IF V_NRCARDAPIO = '0000000001' THEN
                              INSERT INTO NOVOCODIGO
                                 (CDCONTADOR, NRSEQUENCIAL)
                              VALUES
                                 ('CARDAPIO' || V_CDFILIMOVI, LPAD(V_NRCARDAPIO,20,'0'));
                           ELSE
                              UPDATE NOVOCODIGO
                              SET NRSEQUENCIAL = LPAD(V_NRCARDAPIO,20,'0')
                              WHERE CDCONTADOR = 'CARDAPIO' || V_CDFILIMOVI;
                           END IF;

                           INSERT INTO CARDADIA
                              (CDFILIAL, NRCARDAPIO, CDSERVFILI, CDOPERADOR, DTCARDAPIO,  DTMESCARD)
                           VALUES
                              (V_CDFILIMOVI, V_NRCARDAPIO, V_CDSERVFILI, P_CDOPERADOR, P_DT_RECEBIMENTO, TO_DATE('01/'||TO_CHAR(TRUNC(P_DT_RECEBIMENTO),'MM/YYYY')));
                        END IF;
                     END IF;

                     /*Tabela Lancamento Estoque*/
                     SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQUENCIAL),'0')) + 1),10,'0')
                     INTO V_NRLANCESTQ
                     FROM NOVOCODIGO
                     WHERE CDCONTADOR = 'LANCTOEST' || V_CDFILIMOVI;

                     IF V_NRLANCESTQ = '0000000001' THEN
                        INSERT INTO NOVOCODIGO
                           (CDCONTADOR, NRSEQUENCIAL)
                        VALUES
                           ('LANCTOEST' || V_CDFILIMOVI, LPAD(V_NRLANCESTQ,20,'0'));
                     ELSE
                        UPDATE NOVOCODIGO
                        SET NRSEQUENCIAL = LPAD(V_NRLANCESTQ,20,'0')
                        WHERE CDCONTADOR = 'LANCTOEST' || V_CDFILIMOVI;
                     END IF;

                     /*Parmetros da filial*/
                     SELECT MAX(CDEMPRESA), MAX(CDINSCESTA), MAX(CDINSCMUNI)
                     INTO V_CDEMPRESA, V_CDINSCESTA, V_CDINSCMUNI
                     FROM FILIAL
                     WHERE CDFILIAL = V_CDFILIMOVI;

                     IF (P_IDENTRSAIDOP = 'E') THEN
                        /*Incluso do corpo do lanamento de nota fiscal*/
                        INSERT INTO NOTAFISCAL
                           (CDFILIAL, NRLANCTONF, CDEMPRESA, CDINSCESTA, CDINSCMUNI,
                            CDFILIRECE, IDBLOQUEADO, DTENTRSAID, VRPRODUTOS, VRNOTAFISC,
                            IDENTRSAIDOP, CDTIPOOPER, IDSTATUS, IDSISTEMA, USR_RECB_SEQUENCIA)
                        VALUES
                           (V_CDFILIMOVI, V_NRLANCTONF, V_CDEMPRESA, V_CDINSCESTA, V_CDINSCMUNI,
                            V_CDFILIMOVI, 'N', TRUNC(P_DT_RECEBIMENTO), 0, 0,
                            'E', '10', 'P', 'EST', P_RECB_SEQUENCIA);

                        /*Incluso do corpo do lanamento de lanamento de estoque*/
                        INSERT INTO LANCTOESTOQ
                           (CDFILIAL, NRLANCESTQ, NRLANCTONF, IDTPLANCTO, DTLANCESTQ, CDOPERADOR,
                            DSLANCESTQ, IDENTRSAIDOP, CDTIPOOPER, CDFILIMOVI, USR_RECB_SEQUENCIA)
                        VALUES
                           (V_CDFILIMOVI, V_NRLANCESTQ, V_NRLANCTONF, '2', TRUNC(P_DT_RECEBIMENTO), P_CDOPERADOR,
                            'Lanamento Estoque '||TO_CHAR(P_RECB_SEQUENCIA), 'E', '10', V_CDFILIMOVI, P_RECB_SEQUENCIA);
                     ELSE


                       /*Incluso do corpo do lanamento de lanamento de estoque*/
                        INSERT INTO LANCTOESTOQ
                           (CDFILIAL, NRLANCESTQ, NRLANCTONF, IDTPLANCTO, DTLANCESTQ, CDOPERADOR,
                            DSLANCESTQ, CDFILIMOVI, USR_RECB_SEQUENCIA)
                        VALUES
                           (V_CDFILIMOVI, V_NRLANCESTQ, V_NRLANCTONF, '3', TRUNC(P_DT_RECEBIMENTO), P_CDOPERADOR,
                            'Lanamento Estoque '||TO_CHAR(P_RECB_SEQUENCIA), V_CDFILIMOVI, P_RECB_SEQUENCIA);

                        INSERT INTO RETIRADA
                           (CDFILIAL, NRRETIRADA, NRCARDAPIO, DTRETIRADA, CDFILANCESTQ, NRLANCESTQ)
                        VALUES
                           (V_CDFILIMOVI, V_NRRETIRADA, V_NRCARDAPIO ,TRUNC(P_DT_RECEBIMENTO), V_CDFILIMOVI, V_NRLANCESTQ);
                     END IF;

                     IF V_DTAUXILIAR IS NULL THEN
                        V_DTAUXILIAR := TRUNC(P_DT_RECEBIMENTO);
                     END IF;
                  ELSE

                     /*Atualizao da data do corpo dos lanamentos*/
                     UPDATE NOTAFISCAL
                     SET DTENTRSAID = TRUNC(P_DT_RECEBIMENTO)
                     WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

                     /*Atualizao da data do corpo dos lanamentos*/
                     UPDATE LANCTOESTOQ
                     SET DTLANCESTQ = TRUNC(P_DT_RECEBIMENTO)
                     WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

                     /*Atualizao da data do corpo dos lanamentos*/
                     UPDATE RETIRADA
                     SET DTRETIRADA = TRUNC(P_DT_RECEBIMENTO)
                     WHERE CDFILANCESTQ = V_CDFILIMOVI   AND
                           NRLANCESTQ   = V_NRLANCESTQ;

                  END IF;

                  V_VRTOTAITEM := P_QT_VALIDADA * P_VL_UNITARIO_NOTA_FISCAL;
                  V_VRCONTITEM := V_VRTOTAITEM - ((V_VRTOTAITEM) * (NVL(P_PC_DESCONTO,0)/100));

                  /*Incluso de lote padro para produtos*/
                  INSERT INTO LOTE
                     (CDFILIAL, NRLOTEESTQ, NRSUBLOTE, CDPRODUTO, IDSTATLOTE, DTENTRLOTE)
                     (SELECT V_CDFILIMOVI,  ' ', ' ',
                             V_CDPRODUTO, 'L' , SYSDATE
                      FROM PARAMGERAL
                      MINUS
                      SELECT CDFILIAL, NRLOTEESTQ,  NRSUBLOTE,
                            V_CDPRODUTO, 'L', SYSDATE
                      FROM LOTE
                      WHERE  CDFILIAL   =  V_CDFILIMOVI     AND
                             NRLOTEESTQ =  ' '        AND
                             NRSUBLOTE  =  ' '        AND
                             CDPRODUTO  =  V_CDPRODUTO);

                  IF (P_IDENTRSAIDOP = 'E') THEN
                     SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQITPROD),'0000')) + 1), 4, '0')
                     INTO V_NRSEQITPROD
                     FROM ITEMPRODUTO
                     WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

                     /*Incluso na tabela de itens da nota fiscal*/
                     INSERT INTO ITEMPRODUTO
                        (CDFILIAL, NRLANCTONF, NRSEQITPROD, CDPRODUTO, CDPRODEMIS,
                         DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD, VRUNITITEM, VRDESCITEM,
                         VRTOTAITEM, VRCONTITEM, IDCONFORITEM, VRBRUTITEM, CDPRODMOVI,
                         CDFILIMOVI, CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ, NRSUBLOTE,
                         USR_RECB_SEQUENCIA, VRDESPERITEM)
                     VALUES
                        (V_CDFILIMOVI, V_NRLANCTONF, V_NRSEQITPROD, V_CDPRODUTO, V_CDPRODUTO,
                         V_NMPRODUTO, 'S', P_QT_VALIDADA, P_VL_UNITARIO_NOTA_FISCAL, ((V_VRTOTAITEM) * (NVL(P_PC_DESCONTO,0)/100)),
                         V_VRTOTAITEM, V_VRCONTITEM, 'S', V_VRCONTITEM, V_CDPRODESTO,
                         V_CDFILIMOVI, P_ALMOXARIFADO, ' ', ' ', ' ',
                         P_RECB_SEQUENCIA, NVL(P_PC_DESCONTO,0));

                     UPDATE PRODFILI
                     SET DTULTCOMPR = TRUNC(P_DT_RECEBIMENTO),
                         VRULTCOMPR = V_VRCONTITEM/P_QT_VALIDADA
                     WHERE CDFILIAL  = V_CDFILIMOVI      AND
                           CDPRODUTO = V_CDPRODUTO AND
                           NVL(DTULTCOMPR, TRUNC(P_DT_RECEBIMENTO)) <= TRUNC(P_DT_RECEBIMENTO);

                     /*Incluso na tabela de itens de estoque*/
                     INSERT INTO ITLANCTOEST
                        (CDFILIAL, NRLANCESTQ, NRSEQUITEM, CDPRODUTO, QTLANCTOEST,
                         VRUNILANCTO, VRTOTLANCTO, IDTIPOMOVI, DTLANCMOVI, IDORDEMCLC,
                         VRLANCTOEST, QTTOTLANCTO, CDPRODMOVI, VRLANCTOBRUT, IDEVOLESTOQ,
                         IDENTRSAIDOP, CDTIPOOPER, DSLANCESTIT, CDFILIMOVI, CDALMOXARIFE,
                         CDLOCALESTOQ, VRCUSTENTR, NRLOTEESTQ, NRSUBLOTE, USR_RECB_SEQUENCIA, CDOPERADOR)
                     VALUES
                        (V_CDFILIMOVI, V_NRLANCESTQ, V_NRSEQITPROD, V_CDPRODUTO, P_QT_VALIDADA * V_VRFATOCONV,
                         P_VL_UNITARIO_NOTA_FISCAL, V_VRTOTAITEM, '2', TRUNC(P_DT_RECEBIMENTO), '2',
                         V_VRCONTITEM/P_QT_VALIDADA, P_QT_VALIDADA, V_CDPRODESTO, V_VRCONTITEM/P_QT_VALIDADA, 'S',
                         'E', '10', 'Lanamento Estoque '||TO_CHAR(P_RECB_SEQUENCIA), V_CDFILIMOVI, P_ALMOXARIFADO,
                         ' ', V_VRCONTITEM, ' ', ' ', P_RECB_SEQUENCIA, P_CDOPERADOR);
                  ELSE
                     SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(NRSEQUITEM),'0000')) + 1), 4, '0')
                     INTO V_NRSEQITPROD
                     FROM ITLANCTOEST
                     WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

                     /*Incluso na tabela de itens de estoque*/
                     INSERT INTO ITLANCTOEST
                        (CDFILIAL, NRLANCESTQ, NRSEQUITEM, CDPRODUTO, QTLANCTOEST,
                         VRUNILANCTO, VRTOTLANCTO, IDTIPOMOVI, DTLANCMOVI, IDORDEMCLC,
                         VRLANCTOEST, QTTOTLANCTO, CDPRODMOVI, VRLANCTOBRUT, IDEVOLESTOQ,
                         DSLANCESTIT, CDFILIMOVI, CDALMOXARIFE,  CDLOCALESTOQ, VRCUSTENTR,
                         NRLOTEESTQ, NRSUBLOTE, USR_RECB_SEQUENCIA, CDOPERADOR)
                     VALUES
                        (V_CDFILIMOVI, V_NRLANCESTQ, V_NRSEQITPROD, V_CDPRODUTO, P_QT_VALIDADA * V_VRFATOCONV,
                         P_VL_UNITARIO_NOTA_FISCAL, V_VRTOTAITEM, '3', TRUNC(P_DT_RECEBIMENTO), '3',
                         V_VRCONTITEM/P_QT_VALIDADA, P_QT_VALIDADA, V_CDPRODESTO, V_VRCONTITEM/P_QT_VALIDADA, 'S',
                         'Lanamento Estoque '||TO_CHAR(P_RECB_SEQUENCIA), V_CDFILIMOVI, P_ALMOXARIFADO,
                         ' ', V_VRCONTITEM, ' ', ' ', P_RECB_SEQUENCIA, P_CDOPERADOR);

                     INSERT INTO ITEMRETI
                        (CDFILIAL, NRRETIRADA, NRCARDAPIO, NRSEQUITRETI, CDPRODUTO, QTRETIRADA, QTEXTRARETI, CDFIITLANEST, NRLANCESTQ, NRSEQUITEM)
                     VALUES
                         (V_CDFILIMOVI, V_NRRETIRADA, V_NRCARDAPIO, V_NRSEQITPROD, V_CDPRODUTO, P_QT_VALIDADA, P_QT_VALIDADA, V_CDFILIAL, V_NRLANCESTQ, V_NRSEQITPROD);
                  END IF;
               END IF;
            END IF;
         END IF;

         IF (P_IDINCLUSAO = 'E') THEN
            /*Chave para posterior atualizao de estoque*/
            SELECT MAX(I.NRLANCESTQ), MAX(I.DTLANCMOVI)
            INTO V_NRLANCESTQ, V_DTAUXILIAR
            FROM ITLANCTOEST I
            WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA ;


            /*Excluso na tabela de itens da nota fiscal*/
            DELETE FROM ITEMPRODUTO
            WHERE CDPRODUTO          = V_CDPRODUTO AND
                  USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;



            DELETE FROM ITEMRETI
            WHERE CDPRODUTO     = V_CDPRODUTO   AND
                  NRLANCESTQ    = V_NRLANCESTQ  AND
                  CDFILIAL      = V_CDFILIMOVI;

            /*Excluso na tabela de itens de estoque*/
            DELETE FROM ITLANCTOEST
            WHERE CDPRODUTO          = V_CDPRODUTO AND
                  USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

            /*Verificao da existencia de itens no lanamento*/
            SELECT MAX(CDFILIAL)
            INTO V_CDFILIAL
            FROM ITLANCTOEST
            WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

            IF V_CDFILIAL IS NULL THEN
               /*Excluso do corpo do lanamento de nota fiscal*/
               DELETE NOTAFISCAL
               WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;

               /*Excluso da tabela de retiradas de estoque*/
               DELETE RETIRADA
               WHERE CDFILANCESTQ = V_CDFILIMOVI   AND
                     NRLANCESTQ   = V_NRLANCESTQ;

               /*Excluso do corpo do lanamento de lanamento de estoque*/
               DELETE LANCTOESTOQ
               WHERE USR_RECB_SEQUENCIA = P_RECB_SEQUENCIA;
            END IF;
         END IF;

         V_DTINICIAL := NVL(TRUNC(V_DTAUXILIAR),TRUNC(P_DT_RECEBIMENTO));
         IF V_DTINICIAL > TRUNC(P_DT_RECEBIMENTO) THEN
            V_DTINICIAL := TRUNC(P_DT_RECEBIMENTO);
         END IF;

         V_DTFINAL := NVL(TRUNC(V_DTAUXILIAR),TRUNC(P_DT_RECEBIMENTO));
         IF V_DTFINAL < TRUNC(P_DT_RECEBIMENTO) THEN
            V_DTFINAL := TRUNC(P_DT_RECEBIMENTO);
         END IF;

         /*Atualizao de estoque de produtos*/
         ATUALIZA_ESTOQUE(V_CDFILIMOVI, V_DTINICIAL, V_DTFINAL, V_CDFILIMOVI, V_NRLANCESTQ);
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_STP_INTERFACE_TECNISA','5.60.XXX'); END;
/

